==> react-native-rtc-1.0.0.tgz: package/android/src/main/java/com/volcengine/reactnative/vertc/vod/VertcVod.java <==
// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.graphics.SurfaceTexture;
import android.opengl.EGLContext;
import android.util.Log;
import android.view.Surface;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.data.AudioSourceType;
import com.ss.bytertc.engine.data.StreamIndex;
import com.ss.bytertc.engine.data.VideoSourceType;
import com.ss.ttvideoengine.Resolution;
import com.ss.ttvideoengine.TTVideoEngine;
import com.ss.ttvideoengine.VideoEngineCallback;
import com.volcengine.VolcApiEngine.VolcApiEnginePool;

public class VertcVod {
  private String TAG = "VertcVod";

  private TTVideoEngine mVideoEngine;
  private org.json.JSONObject mOptions;
  
  private int mVideoWidth = 1080;
  private int mVideoHeight = 1920;
  private VodVideoEngineCallbackProxy mVodVideoEngineCallbackProxy;
  private OESTextureProcessor mOESTextureProcessor;
  private VideoAudioProcessor mVAProcessor;
  private final OESTextureProcessor.IProcessorCallback mProcessorCallback = new OESTextureProcessor.IProcessorCallback() {
    @Override
    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(new Surface(surface));
      }
    }

    @Override
    public void onSurfaceTextureDestroyed(SurfaceTexture surface) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(null);
      }
    }

    @Override
    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height, long timestamp) {
      mVAProcessor.onFrameAvailable(eglContext, oesTextureId, transformMatrix, width, height);
    }
  };

  public int startVodPlayerCapture(RTCVideo engine, Object ttplayer, org.json.JSONObject options) {
    try {
      stopVodPlayerCapture(engine);

      mVideoEngine = getTTVideoEngine(ttplayer);
      if (mVideoEngine == null) {
        throw new RuntimeException("unknown VideoEngine");
      }
      
      mOptions = options;
      mVAProcessor = new VideoAudioProcessor(engine, options);

      // process TTVideoEngine video
      VideoEngineCallback mVideoEngineCallback = new VideoEngineCallback() {
        @Override
        public void onRenderStart(TTVideoEngine engine) {
          final int videoWidth = engine.getVideoWidth();
          final int videoHeight = engine.getVideoHeight();
          Log.d(TAG, "onRenderStart: " + videoWidth + "x" + videoHeight);
          mVideoWidth = videoWidth;
          mVideoHeight = videoHeight;

          mVAProcessor.updateScreenConfig(videoWidth, videoHeight);
          if (mOESTextureProcessor != null) {
            mOESTextureProcessor.destroy();
          }
          mOESTextureProcessor = new OESTextureProcessor();
          mOESTextureProcessor.initSurfaceTexture(videoWidth, videoHeight, mProcessorCallback);
        }
      };
      mVodVideoEngineCallbackProxy = new VodVideoEngineCallbackProxy(mVideoEngine, mVideoEngineCallback);
      mVideoEngine.setVideoEngineCallback(mVodVideoEngineCallbackProxy.listen());
      // process TTVideoEngine audio
      mVideoEngine.setAudioProcessor(mVAProcessor);
      mVideoEngine.setIntOption(TTVideoEngine.PLAYER_OPTION_SET_VOICE, TTVideoEngine.VOICE_DUMMY);
      mVideoEngine.setIntOption(TTVideoEngine.PLAYER_OPTION_DUMMY_AUDIO_SLEEP, 0);

      // set sourceType to External
      engine.setScreenAudioSourceType(AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL);
      engine.setVideoSourceType(StreamIndex.STREAM_INDEX_SCREEN, VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL);

      OESTextureProcessor textureProcessor = mOESTextureProcessor;
      if (textureProcessor != null) {
        textureProcessor.destroy();
      }
      mOESTextureProcessor = new OESTextureProcessor();
      mOESTextureProcessor.initSurfaceTexture(mVideoWidth, mVideoHeight, mProcessorCallback);
      
      return 0;
    } catch (Exception err) {
      Log.d(TAG, "startVodPlayerCapture fail:" + err.getMessage());
      throw new RuntimeException(err);
    }
  }

  public int stopVodPlayerCapture(RTCVideo engine) {
    // reset sourceType to Internal
    engine.setVideoSourceType(StreamIndex.STREAM_INDEX_SCREEN, VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL);
    engine.setScreenAudioSourceType(AudioSourceType.AUDIO_SOURCE_TYPE_INTERNAL);
    mOptions = null;
    if (mVodVideoEngineCallbackProxy != null) {
      mVodVideoEngineCallbackProxy.reset(mVideoEngine);
      mVodVideoEngineCallbackProxy = null;
    }
    if (mVideoEngine != null) {
      mVideoEngine.setSurfaceHolder(null);
      mVideoEngine.setAudioProcessor(null);
      mVideoEngine.setVideoEngineCallback(null);
      mVideoEngine = null;
    }
    if (mOESTextureProcessor != null) {
      mOESTextureProcessor.destroy();
      mOESTextureProcessor = null;
    }
    if (mVAProcessor != null) {
      mVAProcessor.destory();
      mVAProcessor = null;
    }
    return 0;
  }
  
  private TTVideoEngine getTTVideoEngine(Object arg) {
    if (arg instanceof TTVideoEngine) {
      return (TTVideoEngine)arg;
    }

    Object decoded = VolcApiEnginePool.getInstance().decodeArg(arg, null);
    if (decoded instanceof TTVideoEngine) {
      return (TTVideoEngine)arg;
    }
    
    return null;
  }
}

==> react-native-rtc-1.0.1.tgz: package/android/src/main/java/com/volcengine/reactnative/vertc/vod/VertcVod.java <==
// Copyright © 2022 BytePlusRTC All rights reserved.
// SPDX-License-Identifier: MIT

package com.volcengine.reactnative.vertc.vod;

import android.graphics.SurfaceTexture;
import android.opengl.EGLContext;
import android.util.Log;
import android.view.Surface;

import com.ss.bytertc.engine.RTCVideo;
import com.ss.bytertc.engine.data.AudioSourceType;
import com.ss.bytertc.engine.data.StreamIndex;
import com.ss.bytertc.engine.data.VideoSourceType;
import com.ss.ttvideoengine.Resolution;
import com.ss.ttvideoengine.TTVideoEngine;
import com.ss.ttvideoengine.VideoEngineCallback;
import com.volcengine.VolcApiEngine.VolcApiEnginePool;

public class VertcVod {
  private String TAG = "VertcVod";

  private TTVideoEngine mVideoEngine;
  
  private int mVideoWidth = 1080;
  private int mVideoHeight = 1920;
  private OESTextureProcessor mOESTextureProcessor;
  private VideoAudioProcessor mVAProcessor;
  private final OESTextureProcessor.IProcessorCallback mProcessorCallback = new OESTextureProcessor.IProcessorCallback() {
    @Override
    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(new Surface(surface));
      }
    }

    @Override
    public void onSurfaceTextureDestroyed(SurfaceTexture surface) {
      TTVideoEngine videoEngine = mVideoEngine;
      if (videoEngine != null) {
        videoEngine.setSurface(null);
      }
    }

    @Override
    public void onFrameAvailable(EGLContext eglContext, int oesTextureId, float[] transformMatrix, int width, int height, long timestamp) {
      mVAProcessor.onFrameAvailable(eglContext, oesTextureId, transformMatrix, width, height);
    }
  };

  public int startVodPlayerCapture(RTCVideo engine, Object arg, StreamIndex streamIndex) {
    try {
      mVideoEngine = getTTVideoEngine(arg);
      if (mVideoEngine == null) {
        throw new RuntimeException("unknown VideoEngine");
      }
      stopVodPlayerCapture(engine);

      mVAProcessor = new VideoAudioProcessor(engine);
      var mVideoEngineCallback = new VideoEngineCallback() {
        @Override
        public void onRenderStart(TTVideoEngine engine) {
          final int videoWidth = engine.getVideoWidth();
          final int videoHeight = engine.getVideoHeight();
          Log.d(TAG, "onRenderStart: " + videoWidth + "x" + videoHeight);
          mVideoWidth = videoWidth;
          mVideoHeight = videoHeight;

          mVAProcessor.updateScreenConfig(videoWidth, videoHeight);
          if (mOESTextureProcessor != null) {
            mOESTextureProcessor.destroy();
          }
          mOESTextureProcessor = new OESTextureProcessor();
          mOESTextureProcessor.initSurfaceTexture(videoWidth, videoHeight, mProcessorCallback);
        }
      };
      mVideoEngine.configResolution(Resolution.High);
      mVideoEngine.setVideoEngineCallback(mVideoEngineCallback);
      mVideoEngine.setAudioProcessor(mVAProcessor);
      mVideoEngine.setIntOption(TTVideoEngine.PLAYER_OPTION_SET_VOICE, TTVideoEngine.VOICE_DUMMY);
      mVideoEngine.setIntOption(TTVideoEngine.PLAYER_OPTION_DUMMY_AUDIO_SLEEP, 0);

      engine.setScreenAudioSourceType(AudioSourceType.AUDIO_SOURCE_TYPE_EXTERNAL);
      engine.setVideoSourceType(StreamIndex.STREAM_INDEX_SCREEN, VideoSourceType.VIDEO_SOURCE_TYPE_EXTERNAL);
//
      OESTextureProcessor textureProcessor = mOESTextureProcessor;
      if (textureProcessor != null) {
        textureProcessor.destroy();
      }
      mOESTextureProcessor = new OESTextureProcessor();
      mOESTextureProcessor.initSurfaceTexture(1080, 1920, mProcessorCallback);
      
      return 0;
    } catch (Exception err) {
      Log.d(TAG, "error:" + err.getMessage());
      throw new RuntimeException(err);
    }
  }

  public int stopVodPlayerCapture(RTCVideo engine) {
    engine.setVideoSourceType(StreamIndex.STREAM_INDEX_SCREEN, VideoSourceType.VIDEO_SOURCE_TYPE_INTERNAL);
    if (mVideoEngine != null) {
      mVideoEngine.setSurfaceHolder(null);
      mVideoEngine.setAudioProcessor(null);
      mVideoEngine.setVideoEngineCallback(null);
    }
    if (mOESTextureProcessor != null) {
      mOESTextureProcessor.destroy();
      mOESTextureProcessor = null;
    }
    if (mVAProcessor != null) {
      mVAProcessor.destory();
      mVAProcessor = null;
    }
    return 0;
  }
  
  private TTVideoEngine getTTVideoEngine(Object arg) {
    if (arg instanceof TTVideoEngine) {
      return (TTVideoEngine)arg;
    }

    Object decoded = VolcApiEnginePool.getInstance().decodeArg(arg, null);
    if (decoded instanceof TTVideoEngine) {
      return (TTVideoEngine)arg;
    }
    
    return null;
  }
}
